@@ -108,7 +108,6 @@ typedef struct avl_node_t {
 	struct avl_node_t *left;
 	struct avl_node_t *right;
         const void *item;
-	double domr;
 #ifdef AVL_DEPTH
 	unsigned char depth;
 #endif
@@ -135,7 +134,7 @@ static void avl_rebalance(avl_tree_t *, avl_node_t *);
 #define NODE_DEPTH(n)  ((n) ? (n)->depth : 0)
 #define L_DEPTH(n)     (NODE_DEPTH((n)->left))
 #define R_DEPTH(n)     (NODE_DEPTH((n)->right))
-#define CALC_DEPTH(n)  ((L_DEPTH(n)>R_DEPTH(n)?L_DEPTH(n):R_DEPTH(n)) + 1)
+#define CALC_DEPTH(n)  (unsigned char)((L_DEPTH(n)>R_DEPTH(n)?L_DEPTH(n):R_DEPTH(n)) + 1)
 #endif
 
 static int avl_check_balance(avl_node_t *avlnode) {
